package Bencher::ScenarioR::LogGer::Startup;

our $VERSION = "0.010"; # VERSION

our $results = [
  [
    200,
    "OK",
    [
      {
        errors      => 0.00013,
        modver      => "",
        participant => "use Log::Log4perl + easy_init",
        rate        => 25,
        samples     => 20,
        time        => 41,
        vs_slowest  => 1,
      },
      {
        errors      => 0.00018,
        modver      => "",
        participant => "use Log::Log4perl ()",
        rate        => 25,
        samples     => 20,
        time        => 40,
        vs_slowest  => 1,
      },
      {
        errors      => 8.4e-05,
        modver      => "",
        participant => "use Log::ger + use LGO:Composite (2 outputs + pattern layouts)",
        rate        => 49,
        samples     => 20,
        time        => 21,
        vs_slowest  => 2,
      },
      {
        errors      => 8.5e-05,
        modver      => "",
        participant => "use Log::Log4perl::Tiny :easy",
        rate        => 49,
        samples     => 20,
        time        => 20,
        vs_slowest  => 2,
      },
      {
        errors      => 0.0001,
        modver      => "",
        participant => "use Log::Log4perl::Tiny ()",
        rate        => 49,
        samples     => 20,
        time        => 20,
        vs_slowest  => 2,
      },
      {
        errors      => 0.00014,
        modver      => "1.00",
        participant => "use Log::Any",
        rate        => 49,
        samples     => 20,
        time        => 20,
        vs_slowest  => 2,
      },
      {
        errors      => 3e-05,
        modver      => "",
        participant => "use Log::ger + use LGO:Composite (2 outputs)",
        rate        => 63,
        samples     => 20,
        time        => 16,
        vs_slowest  => 2.6,
      },
      {
        errors      => 0.0001,
        modver      => "",
        participant => "use Log::ger + use LGO:Composite (0 outputs)",
        rate        => 67,
        samples     => 20,
        time        => 15,
        vs_slowest  => 2.7,
      },
      {
        errors      => 7.8e-05,
        modver      => "",
        participant => "use Log::ger::Like::Log4perl",
        rate        => 70,
        samples     => 20,
        time        => 14,
        vs_slowest  => 2.8,
      },
      {
        errors      => 2.8e-05,
        modver      => "",
        participant => "use Log::ger::App",
        rate        => 73,
        samples     => 20,
        time        => 14,
        vs_slowest  => 3,
      },
      {
        errors      => 3.5e-05,
        modver      => "",
        participant => "use Log::Any + use LGA:Screen",
        rate        => 77,
        samples     => 20,
        time        => 13,
        vs_slowest  => 3.1,
      },
      {
        errors      => 2e-05,
        modver      => 1.042,
        participant => "use Log::Any",
        rate        => 91,
        samples     => 20,
        time        => 11,
        vs_slowest  => 3.7,
      },
      {
        errors      => 2.2e-05,
        modver      => "",
        participant => "use Log::ger + use LGO:Screen",
        rate        => 94,
        samples     => 20,
        time        => 11,
        vs_slowest  => 3.8,
      },
      {
        errors      => 2.5e-05,
        modver      => "",
        participant => "use Log::ger + use LGO:File",
        rate        => 95,
        samples     => 21,
        time        => 10,
        vs_slowest  => 3.9,
      },
      {
        errors      => 2.1e-05,
        modver      => "",
        participant => "use Log::ger + use LGP:OptAway",
        rate        => 160,
        samples     => 20,
        time        => 6.3,
        vs_slowest  => 6.4,
      },
      {
        errors      => 2.5e-05,
        modver      => 0.15,
        participant => "use Log::Any",
        rate        => 170,
        samples     => 21,
        time        => 6,
        vs_slowest  => 6.7,
      },
      {
        errors      => 1.7e-05,
        modver      => "",
        participant => "use Log::ger + get_logger()",
        rate        => 290,
        samples     => 20,
        time        => 3.4,
        vs_slowest  => 12,
      },
      {
        errors      => 8.5e-06,
        modver      => "",
        participant => "use Log::ger",
        rate        => 300,
        samples     => 20,
        time        => 3.3,
        vs_slowest  => 12,
      },
      {
        errors      => 5.1e-06,
        modver      => "",
        participant => "use Log::ger ()",
        rate        => 310,
        samples     => 20,
        time        => 3.2,
        vs_slowest  => 13,
      },
      {
        errors      => 1.1e-05,
        modver      => "",
        participant => "use Log::ger::Like::LogAny",
        rate        => 360,
        samples     => 20,
        time        => 2.7,
        vs_slowest  => 15,
      },
      {
        errors      => 7.8e-06,
        modver      => "",
        participant => "baseline",
        rate        => 440,
        samples     => 20,
        time        => 2.3,
        vs_slowest  => 18,
      },
    ],
    {
      "func.bencher_args"              => {
                                            action => "bench",
                                            include_path => ["archive/Log-Any-0.15/lib", "archive/Log-Any-1.00/lib"],
                                            multimodver => "Log::Any",
                                            note => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
                                            scenario_module => "LogGer::Startup",
                                          },
      "func.bencher_version"           => undef,
      "func.cpu_info"                  => [
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 0,
                                              speed                        => 2142.273,
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 1,
                                              speed                        => 2099.945,
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 2,
                                              speed                        => 2036.835,
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 3,
                                              speed                        => 2005.664,
                                              stepping                     => 4,
                                            },
                                          ],
      "func.module_startup"            => undef,
      "func.module_versions"           => {
                                            "__PACKAGE__"                        => 1.039,
                                            "Bencher::Scenario::LogGer::Startup" => undef,
                                            "Benchmark::Dumb"                    => "0.10",
                                            "Devel::Platform::Info"              => 0.16,
                                            "Log::Any"                           => 1.042,
                                            "Log::Any::Adapter::Screen"          => 0.13,
                                            "Log::ger"                           => 0.016,
                                            "Log::ger::App"                      => 0.002,
                                            "Log::ger::Layout::Pattern"          => 0.001,
                                            "Log::ger::Like::Log4perl"           => 0.001,
                                            "Log::ger::Like::LogAny"             => 0.003,
                                            "Log::ger::Output"                   => 0.016,
                                            "Log::ger::Output::Composite"        => 0.007,
                                            "Log::ger::Output::File"             => 0.002,
                                            "Log::ger::Output::Screen"           => 0.005,
                                            "Log::ger::Plugin::OptAway"          => 0.004,
                                            "Log::Log4perl"                      => 1.47,
                                            "Log::Log4perl::Tiny"                => "1.4.0",
                                            "perl"                               => "v5.24.0",
                                            "Sys::Info"                          => 0.78,
                                          },
      "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
      "func.permute"                   => [
                                            "perl",
                                            ["perl"],
                                            "modver",
                                            [1.042, "1.00", 0.15],
                                            "participant",
                                            [0 .. 18],
                                          ],
      "func.platform_info"             => {
                                            archname => "x86_64",
                                            codename => "rosa",
                                            is32bit  => 0,
                                            is64bit  => 1,
                                            kernel   => "linux-3.19.0-32-generic",
                                            kname    => "Linux",
                                            kvers    => "3.19.0-32-generic",
                                            osflag   => "linux",
                                            oslabel  => "LinuxMint",
                                            osname   => "GNU/Linux",
                                            osvers   => 17.3,
                                            source   => {
                                                          "cat /etc/.issue" => "",
                                                          "cat /etc/issue"  => "Linux Mint 17.3 Rosa \\n \\l",
                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 17.3 Rosa\nRelease:\t17.3\nCodename:\trosa",
                                                          "uname -a"        => "Linux backpacker 3.19.0-32-generic #37~14.04.1-Ubuntu SMP Thu Oct 22 09:41:40 UTC 2015 x86_64 x86_64 x86_64 GNU/Linux",
                                                          "uname -m"        => "x86_64",
                                                          "uname -o"        => "GNU/Linux",
                                                          "uname -r"        => "3.19.0-32-generic",
                                                          "uname -s"        => "Linux",
                                                        },
                                          },
      "func.precision"                 => 0,
      "func.scenario_module"           => "Bencher::Scenario::LogGer::Startup",
      "func.scenario_module_md5sum"    => "e9cb726ee7518aab837eeef35114d230",
      "func.scenario_module_mtime"     => 1499940098,
      "func.scenario_module_sha1sum"   => "33e1d816237b29e0148d762c87f167c9bb2995e1",
      "func.scenario_module_sha256sum" => "a74e67332622cebd358fbd72adff8ce7ce33fd7a4277b05811ad5f275840498e",
      "func.time_factor"               => 1000,
      "func.time_start"                => 1499940805.90074,
      "table.field_aligns"             => [
                                            "left",
                                            "left",
                                            "left",
                                            "number",
                                            "number",
                                            "number",
                                            "number",
                                            "number",
                                          ],
      "table.field_units"              => [undef, undef, undef, "/s", "ms"],
      "table.fields"                   => [
                                            "participant",
                                            "dataset",
                                            "modver",
                                            "rate",
                                            "time",
                                            "vs_slowest",
                                            "errors",
                                            "samples",
                                          ],
    },
  ],
  [
    200,
    "OK",
    [
      {
        errors      => 5.5e-05,
        modver      => "",
        participant => "use Log::ger + use LGO:Composite (2 outputs + pattern layouts)",
        rate        => 50,
        samples     => 20,
        time        => 20,
        vs_slowest  => 1,
      },
      {
        errors      => 5.7e-05,
        modver      => "",
        participant => "use Log::ger + use LGO:Composite (2 outputs)",
        rate        => 63,
        samples     => 20,
        time        => 16,
        vs_slowest  => 1.3,
      },
      {
        errors      => 2.5e-05,
        modver      => "",
        participant => "use Log::ger + use LGO:Composite (0 outputs)",
        rate        => 71,
        samples     => 20,
        time        => 14,
        vs_slowest  => 1.4,
      },
      {
        errors      => 2.1e-05,
        modver      => "",
        participant => "use Log::ger::Like::Log4perl",
        rate        => 71,
        samples     => 20,
        time        => 14,
        vs_slowest  => 1.4,
      },
      {
        errors      => 3.8e-05,
        modver      => "",
        participant => "use Log::ger::App",
        rate        => 75,
        samples     => 20,
        time        => 13,
        vs_slowest  => 1.5,
      },
      {
        errors      => 1.6e-05,
        modver      => "",
        participant => "use Log::ger + use LGO:Screen",
        rate        => 94,
        samples     => 21,
        time        => 11,
        vs_slowest  => 1.9,
      },
      {
        errors      => 1.4e-05,
        modver      => "",
        participant => "use Log::ger + use LGO:File",
        rate        => 96,
        samples     => 20,
        time        => 10,
        vs_slowest  => 1.9,
      },
      {
        errors      => 1.7e-05,
        modver      => "",
        participant => "use Log::ger + use LGP:OptAway",
        rate        => 170,
        samples     => 22,
        time        => 5.8,
        vs_slowest  => 3.5,
      },
      {
        errors      => 9e-06,
        modver      => 0.011,
        participant => "use Log::ger",
        rate        => 210,
        samples     => 20,
        time        => 4.8,
        vs_slowest  => 4.2,
      },
      {
        errors      => 1.1e-05,
        modver      => 0.011,
        participant => "use Log::ger + get_logger()",
        rate        => 210,
        samples     => 20,
        time        => 4.7,
        vs_slowest  => 4.3,
      },
      {
        errors      => 1.1e-05,
        modver      => 0.012,
        participant => "use Log::ger + get_logger()",
        rate        => 210,
        samples     => 20,
        time        => 4.7,
        vs_slowest  => 4.3,
      },
      {
        errors      => 1.9e-05,
        modver      => 0.011,
        participant => "use Log::ger ()",
        rate        => 220,
        samples     => 20,
        time        => 4.6,
        vs_slowest  => 4.3,
      },
      {
        errors      => 9.8e-06,
        modver      => 0.012,
        participant => "use Log::ger",
        rate        => 220,
        samples     => 21,
        time        => 4.6,
        vs_slowest  => 4.4,
      },
      {
        errors      => 8.4e-06,
        modver      => 0.012,
        participant => "use Log::ger ()",
        rate        => 230,
        samples     => 21,
        time        => 4.4,
        vs_slowest  => 4.6,
      },
      {
        errors      => 6.5e-06,
        modver      => 0.008,
        participant => "use Log::ger + get_logger()",
        rate        => 250,
        samples     => 20,
        time        => 4,
        vs_slowest  => 5.1,
      },
      {
        errors      => 1.2e-05,
        modver      => 0.006,
        participant => "use Log::ger + get_logger()",
        rate        => 260,
        samples     => 20,
        time        => 3.9,
        vs_slowest  => 5.1,
      },
      {
        errors      => 6e-06,
        modver      => 0.009,
        participant => "use Log::ger + get_logger()",
        rate        => 260,
        samples     => 22,
        time        => 3.9,
        vs_slowest  => 5.1,
      },
      {
        errors      => 1.1e-05,
        modver      => 0.005,
        participant => "use Log::ger + get_logger()",
        rate        => 260,
        samples     => 20,
        time        => 3.9,
        vs_slowest  => 5.2,
      },
      {
        errors      => 1.2e-05,
        modver      => 0.007,
        participant => "use Log::ger ()",
        rate        => 260,
        samples     => 20,
        time        => 3.9,
        vs_slowest  => 5.2,
      },
      {
        errors      => 6.9e-06,
        modver      => 0.007,
        participant => "use Log::ger + get_logger()",
        rate        => 260,
        samples     => 20,
        time        => 3.9,
        vs_slowest  => 5.2,
      },
      {
        errors      => 9.4e-06,
        modver      => "0.010",
        participant => "use Log::ger + get_logger()",
        rate        => 260,
        samples     => 23,
        time        => 3.9,
        vs_slowest  => 5.2,
      },
      {
        errors      => 8.3e-06,
        modver      => 0.005,
        participant => "use Log::ger",
        rate        => 260,
        samples     => 20,
        time        => 3.9,
        vs_slowest  => 5.2,
      },
      {
        errors      => 1.1e-05,
        modver      => 0.009,
        participant => "use Log::ger ()",
        rate        => 260,
        samples     => 20,
        time        => 3.9,
        vs_slowest  => 5.2,
      },
      {
        errors      => 1.6e-05,
        modver      => 0.008,
        participant => "use Log::ger ()",
        rate        => 260,
        samples     => 20,
        time        => 3.9,
        vs_slowest  => 5.2,
      },
      {
        errors      => 4.7e-06,
        modver      => 0.009,
        participant => "use Log::ger",
        rate        => 260,
        samples     => 20,
        time        => 3.9,
        vs_slowest  => 5.2,
      },
      {
        errors      => 9.6e-06,
        modver      => 0.008,
        participant => "use Log::ger",
        rate        => 260,
        samples     => 21,
        time        => 3.9,
        vs_slowest  => 5.2,
      },
      {
        errors      => 7.6e-06,
        modver      => 0.006,
        participant => "use Log::ger",
        rate        => 260,
        samples     => 20,
        time        => 3.9,
        vs_slowest  => 5.2,
      },
      {
        errors      => 1.1e-05,
        modver      => 0.006,
        participant => "use Log::ger ()",
        rate        => 260,
        samples     => 20,
        time        => 3.9,
        vs_slowest  => 5.2,
      },
      {
        errors      => 9.1e-06,
        modver      => "0.010",
        participant => "use Log::ger",
        rate        => 260,
        samples     => 20,
        time        => 3.8,
        vs_slowest  => 5.2,
      },
      {
        errors      => 1.1e-05,
        modver      => 0.007,
        participant => "use Log::ger",
        rate        => 260,
        samples     => 20,
        time        => 3.8,
        vs_slowest  => 5.3,
      },
      {
        errors      => 6.8e-06,
        modver      => "0.010",
        participant => "use Log::ger ()",
        rate        => 270,
        samples     => 21,
        time        => 3.8,
        vs_slowest  => 5.4,
      },
      {
        errors      => 1.5e-05,
        modver      => 0.005,
        participant => "use Log::ger ()",
        rate        => 270,
        samples     => 20,
        time        => 3.8,
        vs_slowest  => 5.4,
      },
      {
        errors      => 1.4e-05,
        modver      => 0.016,
        participant => "use Log::ger",
        rate        => 320,
        samples     => 20,
        time        => 3.1,
        vs_slowest  => 6.5,
      },
      {
        errors      => 7.1e-06,
        modver      => 0.016,
        participant => "use Log::ger + get_logger()",
        rate        => 320,
        samples     => 20,
        time        => 3.1,
        vs_slowest  => 6.5,
      },
      {
        errors      => 1.1e-05,
        modver      => 0.016,
        participant => "use Log::ger ()",
        rate        => 330,
        samples     => 21,
        time        => 3.1,
        vs_slowest  => 6.6,
      },
      {
        errors      => 4.1e-06,
        modver      => "",
        participant => "use Log::ger::Like::LogAny",
        rate        => 380,
        samples     => 21,
        time        => 2.6,
        vs_slowest  => 7.7,
      },
      {
        errors      => 8.3e-06,
        modver      => "",
        participant => "baseline",
        rate        => 450,
        samples     => 20,
        time        => 2.2,
        vs_slowest  => 9,
      },
    ],
    {
      "func.bencher_args"              => {
                                            action => "bench",
                                            include_participant_pattern => "Log::ger|baseline",
                                            include_path => [
                                              "archive/Log-ger-0.005/lib",
                                              "archive/Log-ger-0.006/lib",
                                              "archive/Log-ger-0.007/lib",
                                              "archive/Log-ger-0.008/lib",
                                              "archive/Log-ger-0.009/lib",
                                              "archive/Log-ger-0.010/lib",
                                              "archive/Log-ger-0.011/lib",
                                              "archive/Log-ger-0.012/lib",
                                              "archive/Log-ger-0.016/lib",
                                            ],
                                            multimodver => "Log::ger",
                                            note => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
                                            scenario_module => "LogGer::Startup",
                                          },
      "func.bencher_version"           => undef,
      "func.cpu_info"                  => [
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 0,
                                              speed                        => 2208.718,
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 1,
                                              speed                        => 2210.414,
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 2,
                                              speed                        => 2199.257,
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 3,
                                              speed                        => 2257.281,
                                              stepping                     => 4,
                                            },
                                          ],
      "func.module_startup"            => undef,
      "func.module_versions"           => {
                                            "__PACKAGE__"                        => 1.039,
                                            "Bencher::Scenario::LogGer::Startup" => undef,
                                            "Benchmark::Dumb"                    => "0.10",
                                            "Devel::Platform::Info"              => 0.16,
                                            "Log::ger"                           => 0.016,
                                            "Log::ger::App"                      => 0.002,
                                            "Log::ger::Layout::Pattern"          => 0.001,
                                            "Log::ger::Like::Log4perl"           => 0.001,
                                            "Log::ger::Like::LogAny"             => 0.003,
                                            "Log::ger::Output"                   => 0.016,
                                            "Log::ger::Output::Composite"        => 0.007,
                                            "Log::ger::Output::File"             => 0.002,
                                            "Log::ger::Output::Screen"           => 0.005,
                                            "Log::ger::Plugin::OptAway"          => 0.004,
                                            "perl"                               => "v5.24.0",
                                            "Sys::Info"                          => 0.78,
                                          },
      "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
      "func.permute"                   => [
                                            "perl",
                                            ["perl"],
                                            "modver",
                                            [0.008, "0.010", 0.007, 0.016, 0.005, 0.012, 0.011, 0.006, 0.009],
                                            "participant",
                                            [0 .. 12],
                                          ],
      "func.platform_info"             => {
                                            archname => "x86_64",
                                            codename => "rosa",
                                            is32bit  => 0,
                                            is64bit  => 1,
                                            kernel   => "linux-3.19.0-32-generic",
                                            kname    => "Linux",
                                            kvers    => "3.19.0-32-generic",
                                            osflag   => "linux",
                                            oslabel  => "LinuxMint",
                                            osname   => "GNU/Linux",
                                            osvers   => 17.3,
                                            source   => {
                                                          "cat /etc/.issue" => "",
                                                          "cat /etc/issue"  => "Linux Mint 17.3 Rosa \\n \\l",
                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 17.3 Rosa\nRelease:\t17.3\nCodename:\trosa",
                                                          "uname -a"        => "Linux backpacker 3.19.0-32-generic #37~14.04.1-Ubuntu SMP Thu Oct 22 09:41:40 UTC 2015 x86_64 x86_64 x86_64 GNU/Linux",
                                                          "uname -m"        => "x86_64",
                                                          "uname -o"        => "GNU/Linux",
                                                          "uname -r"        => "3.19.0-32-generic",
                                                          "uname -s"        => "Linux",
                                                        },
                                          },
      "func.precision"                 => 0,
      "func.scenario_module"           => "Bencher::Scenario::LogGer::Startup",
      "func.scenario_module_md5sum"    => "e9cb726ee7518aab837eeef35114d230",
      "func.scenario_module_mtime"     => 1499940098,
      "func.scenario_module_sha1sum"   => "33e1d816237b29e0148d762c87f167c9bb2995e1",
      "func.scenario_module_sha256sum" => "a74e67332622cebd358fbd72adff8ce7ce33fd7a4277b05811ad5f275840498e",
      "func.time_factor"               => 1000,
      "func.time_start"                => 1499940814.73655,
      "table.field_aligns"             => [
                                            "left",
                                            "left",
                                            "left",
                                            "number",
                                            "number",
                                            "number",
                                            "number",
                                            "number",
                                          ],
      "table.field_units"              => [undef, undef, undef, "/s", "ms"],
      "table.fields"                   => [
                                            "participant",
                                            "dataset",
                                            "modver",
                                            "rate",
                                            "time",
                                            "vs_slowest",
                                            "errors",
                                            "samples",
                                          ],
    },
  ],
];

1;
# ABSTRACT: Measure startup overhead of Log::ger vs other logging libraries

=head1 DESCRIPTION

This module is automatically generated by Pod::Weaver::Plugin::Bencher::Scenario during distribution build.

A Bencher::ScenarioR::* module contains the raw result of sample benchmark and might be useful for some stuffs later.

